# yamapan

Yet Another MetA worksPAce maNager for ROS 2

## Getting Started

```sh
pipx install yamapan
echo "ros_install_prefix = \"/opt/ros/$ROS_DISTRO\"" > ~/.yamapan.toml
cd <path-to-your-ros-2-workspace>
yamapan init
```
